From 33cc612e40c701870edb3759c2efa8053851a503 Mon Sep 17 00:00:00 2001
From: Heiko <61519853+htcfreek@users.noreply.github.com>
Date: Mon, 24 Mar 2025 19:39:08 +0100
Subject: [PATCH] [CmdPal] Fixes for Exts: All Apps, System Commands, Time And
Date (#38103)
## Summary of the Pull Request
All apps:
- Fix missing second command for opnening settings page
Time and Date plugin:
- fix for missing settings list in global plugin manager
- fix for wrong page title
system plugin
- fix for missing settings page in global plugin manager
- fix for missing open button on plugin list
- ~fix for wrong icon for firmware boot~
- fix for wrong subtitle for ipv6
- fix for wrong details for mac address
- fix for wrong layout of network details
- layout improvements for network details
- change default value for "hide disconected networks" to $false
- rename empty recycle bin setting to "Hide Empty Recycle Bin command"



## PR Checklist
- [ ] **Closes:** #xxx
- [ ] **Communication:** I've discussed this with core contributors already. If work hasn't been agreed, this work might be rejected
- [ ] **Tests:** Added/updated and all pass
- [ ] **Localization:** All end user facing strings can be localized
- [ ] **Dev docs:** Added/updated
- [ ] **New binaries:** Added on the required places
- [ ] [JSON for signing](https://github.com/microsoft/PowerToys/blob/main/.pipelines/ESRPSigning_core.json) for new binaries
- [ ] [WXS for installer](https://github.com/microsoft/PowerToys/blob/main/installer/PowerToysSetup/Product.wxs) for new binaries and localization folder
- [ ] [YML for CI pipeline](https://github.com/microsoft/PowerToys/blob/main/.pipelines/ci/templates/build-powertoys-steps.yml) for new test projects
- [ ] [YML for signed pipeline](https://github.com/microsoft/PowerToys/blob/main/.pipelines/release.yml)
- [ ] **Documentation updated:** If checked, please file a pull request on [our docs repo](https://github.com/MicrosoftDocs/windows-uwp/tree/docs/hub/powertoys) and link it here: #xxx
## Detailed Description of the Pull Request / Additional comments
## Validation Steps Performed
---
.../AllAppsCommandProvider.cs | 6 +-
.../Helpers/Commands.cs | 15 +++--
.../Helpers/NetworkConnectionProperties.cs | 64 +++++++++++--------
.../Helpers/SettingsManager.cs | 16 ++---
.../Pages/SystemCommandPage.cs | 1 +
.../Properties/Resources.Designer.cs | 27 +++++---
.../Properties/Resources.resx | 7 +-
.../SystemCommandExtensionProvider.cs | 3 +-
.../SystemCommandsCache.cs | 2 +-
.../Properties/Resources.Designer.cs | 2 +-
.../Properties/Resources.resx | 2 +-
.../TimeDateCommandsProvider.cs | 1 +
12 files changed, 87 insertions(+), 59 deletions(-)
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.Apps/AllAppsCommandProvider.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.Apps/AllAppsCommandProvider.cs
index c90b45373f..be245bb48a 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.Apps/AllAppsCommandProvider.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.Apps/AllAppsCommandProvider.cs
@@ -22,7 +22,11 @@ public partial class AllAppsCommandProvider : CommandProvider
Icon = IconHelpers.FromRelativePath("Assets\\AllApps.svg");
Settings = AllAppsSettings.Instance.Settings;
- _listItem = new(Page) { Subtitle = Resources.search_installed_apps };
+ _listItem = new(Page)
+ {
+ Subtitle = Resources.search_installed_apps,
+ MoreCommands = [new CommandContextItem(AllAppsSettings.Instance.Settings.SettingsPage)],
+ };
}
public override ICommandItem[] TopLevelCommands() => [_listItem];
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/NetworkConnectionProperties.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/NetworkConnectionProperties.cs
index ce050e95fd..9afb39b6f1 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/NetworkConnectionProperties.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/NetworkConnectionProperties.cs
@@ -19,6 +19,14 @@ namespace Microsoft.CmdPal.Ext.System.Helpers;
///
internal sealed class NetworkConnectionProperties
{
+ ///
+ /// Decimal unicode value for green circle emoji.
+ /// We need to generate it in the code because it does not render using Markdown emoji syntax or Unicode character syntax.
+ ///
+ ///
+ ///
+ private const int GreenCircleCharacter = 128994;
+
///
/// Gets the name of the adapter
///
@@ -161,12 +169,12 @@ internal sealed class NetworkConnectionProperties
/// String with the details
internal string GetAdapterDetails()
{
- return $"{Resources.Microsoft_plugin_sys_AdapterName}: {Adapter}" +
- $"\n{Resources.Microsoft_plugin_sys_PhysicalAddress}: {PhysicalAddress}" +
- $"\n{Resources.Microsoft_plugin_sys_Speed}: {GetFormattedSpeedValue(Speed)}" +
- $"\n{Resources.Microsoft_plugin_sys_Type}: {GetAdapterTypeAsString(Type)}" +
- $"\n{Resources.Microsoft_plugin_sys_State}: " + (State == OperationalStatus.Up ? Resources.Microsoft_plugin_sys_Connected : Resources.Microsoft_plugin_sys_Disconnected) +
- $"\n{Resources.Microsoft_plugin_sys_ConnectionName}: {ConnectionName}";
+ return $"**{Resources.Microsoft_plugin_sys_AdapterName}:** {Adapter}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_State}:** " + (State == OperationalStatus.Up ? char.ConvertFromUtf32(GreenCircleCharacter) + " " + Resources.Microsoft_plugin_sys_Connected : ":red_circle: " + Resources.Microsoft_plugin_sys_Disconnected) +
+ $"\n\n**{Resources.Microsoft_plugin_sys_PhysicalAddress}:** {PhysicalAddress}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_Speed}:** {GetFormattedSpeedValue(Speed)}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_Type}:** {GetAdapterTypeAsString(Type)}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_ConnectionName}:** {ConnectionName}";
}
///
@@ -175,24 +183,24 @@ internal sealed class NetworkConnectionProperties
/// String with the details
internal string GetConnectionDetails()
{
- return $"{Resources.Microsoft_plugin_sys_ConnectionName}: {ConnectionName}" +
- $"\n{Resources.Microsoft_plugin_sys_State}: " + (State == OperationalStatus.Up ? Resources.Microsoft_plugin_sys_Connected : Resources.Microsoft_plugin_sys_Disconnected) +
- $"\n{Resources.Microsoft_plugin_sys_Type}: {GetAdapterTypeAsString(Type)}" +
- $"\n{Resources.Microsoft_plugin_sys_Suffix}: {Suffix}" +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip4Address}: ", IPv4) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip4SubnetMask}: ", IPv4Mask) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip6Address}:\n\t", IPv6Global) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip6Temp}:\n\t", IPv6Temporary) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip6Link}:\n\t", IPv6LinkLocal) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip6Site}:\n\t", IPv6SiteLocal) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Ip6Unique}:\n\t", IPv6UniqueLocal) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Gateways}:\n\t", Gateways) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Dhcp}:\n\t", DhcpServers == null ? string.Empty : DhcpServers) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Dns}:\n\t", DnsServers == null ? string.Empty : DnsServers) +
- CreateIpInfoForDetailsText($"{Resources.Microsoft_plugin_sys_Wins}:\n\t", WinsServers == null ? string.Empty : WinsServers) +
- $"\n\n{Resources.Microsoft_plugin_sys_AdapterName}: {Adapter}" +
- $"\n{Resources.Microsoft_plugin_sys_PhysicalAddress}: {PhysicalAddress}" +
- $"\n{Resources.Microsoft_plugin_sys_Speed}: {GetFormattedSpeedValue(Speed)}";
+ return $"**{Resources.Microsoft_plugin_sys_ConnectionName}:** {ConnectionName}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_State}:** " + (State == OperationalStatus.Up ? char.ConvertFromUtf32(GreenCircleCharacter) + " " + Resources.Microsoft_plugin_sys_Connected : ":red_circle: " + Resources.Microsoft_plugin_sys_Disconnected) +
+ $"\n\n**{Resources.Microsoft_plugin_sys_Type}:** {GetAdapterTypeAsString(Type)}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_Suffix}:** {Suffix}" +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip4Address}:** ", IPv4) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip4SubnetMask}:** ", IPv4Mask) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip6Address}:**\n\n* ", IPv6Global) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip6Temp}:**\n\n* ", IPv6Temporary) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip6Link}:**\n\n* ", IPv6LinkLocal) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip6Site}:**\n\n* ", IPv6SiteLocal) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Ip6Unique}:**\n\n* ", IPv6UniqueLocal) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Gateways}:**\n\n* ", Gateways) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Dhcp}:**\n\n* ", DhcpServers == null ? string.Empty : DhcpServers) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Dns}:**\n\n* ", DnsServers == null ? string.Empty : DnsServers) +
+ CreateIpInfoForDetailsText($"**{Resources.Microsoft_plugin_sys_Wins}:**\n\n* ", WinsServers == null ? string.Empty : WinsServers) +
+ $"\n\n**{Resources.Microsoft_plugin_sys_AdapterName}:** {Adapter}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_PhysicalAddress}:** {PhysicalAddress}" +
+ $"\n\n**{Resources.Microsoft_plugin_sys_Speed}:** {GetFormattedSpeedValue(Speed)}";
}
///
@@ -304,13 +312,13 @@ internal sealed class NetworkConnectionProperties
switch (property)
{
case string:
- return $"\n{title}{property}";
+ return string.IsNullOrWhiteSpace(property) ? string.Empty : $"\n\n{title}{property}";
case List listString:
- return listString.Count == 0 ? string.Empty : $"\n{title}{string.Join("\n\t", property)}";
+ return listString.Count == 0 ? string.Empty : $"\n\n{title}{string.Join("\n\n* ", property)}";
case List listIP:
- return listIP.Count == 0 ? string.Empty : $"\n{title}{string.Join("\n\t", property)}";
+ return listIP.Count == 0 ? string.Empty : $"\n\n{title}{string.Join("\n\n* ", property)}";
case IPAddressCollection collectionIP:
- return collectionIP.Count == 0 ? string.Empty : $"\n{title}{string.Join("\n\t", property)}";
+ return collectionIP.Count == 0 ? string.Empty : $"\n\n{title}{string.Join("\n\n* ", property)}";
case null:
return string.Empty;
default:
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/SettingsManager.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/SettingsManager.cs
index 7f43027156..9d51c42615 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/SettingsManager.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/SettingsManager.cs
@@ -25,23 +25,23 @@ public class SettingsManager : JsonSettingsManager
Resources.Microsoft_plugin_sys_RecycleBin_ShowEmptySuccessMessage,
false); // TODO -- double check default value
- private readonly ToggleSetting _showSeparateResultForEmptyRecycleBin = new(
- Namespaced(nameof(ShowSeparateResultForEmptyRecycleBin)),
- Resources.Microsoft_plugin_sys_RecycleBin_ShowEmptySeparate,
- Resources.Microsoft_plugin_sys_RecycleBin_ShowEmptySeparate,
- true); // TODO -- double check default value
+ private readonly ToggleSetting _hideEmptyRecycleBin = new(
+ Namespaced(nameof(HideEmptyRecycleBin)),
+ Resources.Microsoft_plugin_sys_RecycleBin_HideEmpty,
+ Resources.Microsoft_plugin_sys_RecycleBin_HideEmpty,
+ false);
private readonly ToggleSetting _hideDisconnectedNetworkInfo = new(
Namespaced(nameof(HideDisconnectedNetworkInfo)),
Resources.Microsoft_plugin_ext_settings_hideDisconnectedNetworkInfo,
Resources.Microsoft_plugin_ext_settings_hideDisconnectedNetworkInfo,
- true); // TODO -- double check default value
+ false);
public bool ShowDialogToConfirmCommand => _showDialogToConfirmCommand.Value;
public bool ShowSuccessMessageAfterEmptyingRecycleBin => _showSuccessMessageAfterEmptyingRecycleBin.Value;
- public bool ShowSeparateResultForEmptyRecycleBin => _showSeparateResultForEmptyRecycleBin.Value;
+ public bool HideEmptyRecycleBin => _hideEmptyRecycleBin.Value;
public bool HideDisconnectedNetworkInfo => _hideDisconnectedNetworkInfo.Value;
@@ -60,7 +60,7 @@ public class SettingsManager : JsonSettingsManager
Settings.Add(_showDialogToConfirmCommand);
Settings.Add(_showSuccessMessageAfterEmptyingRecycleBin);
- Settings.Add(_showSeparateResultForEmptyRecycleBin);
+ Settings.Add(_hideEmptyRecycleBin);
Settings.Add(_hideDisconnectedNetworkInfo);
// Load settings from file upon initialization
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Pages/SystemCommandPage.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Pages/SystemCommandPage.cs
index 3c81f94421..7bfd7bb4e4 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Pages/SystemCommandPage.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Pages/SystemCommandPage.cs
@@ -15,6 +15,7 @@ public sealed partial class SystemCommandPage : ListPage
public SystemCommandPage(SettingsManager settingsManager)
{
Title = Resources.Microsoft_plugin_ext_system_page_name;
+ Name = Resources.Microsoft_plugin_ext_system_page_name;
Icon = IconHelpers.FromRelativePath("Assets\\SystemCommand.svg");
_settingsManager = settingsManager;
ShowDetails = true;
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.Designer.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.Designer.cs
index 76db4cb232..6aa26a7b0d 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.Designer.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.Designer.cs
@@ -159,6 +159,15 @@ namespace Microsoft.CmdPal.Ext.System {
}
}
+ ///
+ /// Looks up a localized string similar to Adapter Details.
+ ///
+ public static string Microsoft_plugin_ext_adapter_details {
+ get {
+ return ResourceManager.GetString("Microsoft_plugin_ext_adapter_details", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Connection Details.
///
@@ -528,6 +537,15 @@ namespace Microsoft.CmdPal.Ext.System {
}
}
+ ///
+ /// Looks up a localized string similar to Hide the Empty Recycle Bin command.
+ ///
+ public static string Microsoft_plugin_sys_RecycleBin_HideEmpty {
+ get {
+ return ResourceManager.GetString("Microsoft_plugin_sys_RecycleBin_HideEmpty", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Recycle Bin is empty..
///
@@ -546,15 +564,6 @@ namespace Microsoft.CmdPal.Ext.System {
}
}
- ///
- /// Looks up a localized string similar to Show separate result for Empty Recycle Bin command.
- ///
- public static string Microsoft_plugin_sys_RecycleBin_ShowEmptySeparate {
- get {
- return ResourceManager.GetString("Microsoft_plugin_sys_RecycleBin_ShowEmptySeparate", resourceCulture);
- }
- }
-
///
/// Looks up a localized string similar to Show a success message after emptying the Recycle Bin.
///
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.resx b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.resx
index 708dabe0d1..e71e8a8d01 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.resx
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Properties/Resources.resx
@@ -151,6 +151,9 @@
Connection Details
+
+ Adapter Details
+
Copy to clipboard
@@ -309,8 +312,8 @@
Empty Recycle Bin
This should align to the action in Windows of emptying the recycle bin on your computer.
-
- Show separate result for Empty Recycle Bin command
+
+ Hide the Empty Recycle Bin command
Show a success message after emptying the Recycle Bin
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandExtensionProvider.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandExtensionProvider.cs
index ff13540edf..be89cf75fd 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandExtensionProvider.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandExtensionProvider.cs
@@ -22,13 +22,14 @@ public partial class SystemCommandExtensionProvider : CommandProvider
_commands = [
new CommandItem(Page)
{
- Title = DisplayName,
+ Title = Resources.Microsoft_plugin_ext_system_page_name,
Icon = Page.Icon,
MoreCommands = [new CommandContextItem(_settingsManager.Settings.SettingsPage)],
},
];
Icon = Page.Icon;
+ Settings = _settingsManager.Settings;
}
public override ICommandItem[] TopLevelCommands()
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandsCache.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandsCache.cs
index ac0811f27f..a2a61b2b50 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandsCache.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/SystemCommandsCache.cs
@@ -20,7 +20,7 @@ public sealed partial class SystemCommandsCache
{
var isBootedInUefiMode = Win32Helpers.GetSystemFirmwareType() == FirmwareType.Uefi;
- var separateEmptyRB = manager.ShowSeparateResultForEmptyRecycleBin;
+ var separateEmptyRB = manager.HideEmptyRecycleBin;
var confirmSystemCommands = manager.ShowDialogToConfirmCommand;
var showSuccessOnEmptyRB = manager.ShowSuccessMessageAfterEmptyingRecycleBin;
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.Designer.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.Designer.cs
index 0d6be76c7e..8891e81c2b 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.Designer.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.Designer.cs
@@ -268,7 +268,7 @@ namespace Microsoft.CmdPal.Ext.TimeDate {
}
///
- /// Looks up a localized string similar to Time & Date.
+ /// Looks up a localized string similar to Time and Date.
///
public static string Microsoft_plugin_timedate_main_page_title {
get {
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.resx b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.resx
index efcddf4ca8..a3974911c4 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.resx
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/Properties/Resources.resx
@@ -370,7 +370,7 @@
Error: Invalid input
- Time & Date
+ Time and Date
Valid prefixes: 'u' for Unix Timestamp, 'ums' for Unix Timestamp in milliseconds, 'ft' for Windows file time
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/TimeDateCommandsProvider.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/TimeDateCommandsProvider.cs
index 228585fa1c..05597c4553 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/TimeDateCommandsProvider.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.TimeDate/TimeDateCommandsProvider.cs
@@ -32,6 +32,7 @@ public partial class TimeDateCommandsProvider : CommandProvider
};
Icon = _timeDateExtensionPage.Icon;
+ Settings = _settingsManager.Settings;
}
private string GetTranslatedPluginDescription()
diff --git a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/Commands.cs b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/Commands.cs
index 039e7c55b3..1459b83bc6 100644
--- a/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/Commands.cs
+++ b/src/modules/cmdpal/Exts/Microsoft.CmdPal.Ext.System/Helpers/Commands.cs
@@ -33,11 +33,11 @@ internal static class Commands
/// Returns a list with all system command results
///
/// Value indicating if the system is booted in uefi mode
/// Value indicating if we should show two results for Recycle Bin.
/// A value indicating if the user should confirm the system commands
/// Show a success message after empty Recycle Bin.
/// A list of all results
- public static List GetSystemCommands(bool isUefi, bool splitRecycleBinResults, bool confirmCommands, bool emptyRBSuccessMessage)
+ public static List GetSystemCommands(bool isUefi, bool hideEmptyRecycleBin, bool confirmCommands, bool emptyRBSuccessMessage)
{
var results = new List();
results.AddRange(new[]
@@ -81,7 +81,7 @@ internal static class Commands
});
// Show Recycle Bin results based on setting.
- if (splitRecycleBinResults)
+ if (!hideEmptyRecycleBin)
{
results.AddRange(new[]
{
@@ -142,6 +142,7 @@ internal static class Commands
}
CompositeFormat sysIpv4DescriptionCompositeFormate = CompositeFormat.Parse(Resources.Microsoft_plugin_sys_ip4_description);
+ CompositeFormat sysIpv6DescriptionCompositeFormate = CompositeFormat.Parse(Resources.Microsoft_plugin_sys_ip6_description);
CompositeFormat sysMacDescriptionCompositeFormate = CompositeFormat.Parse(Resources.Microsoft_plugin_sys_mac_description);
var hideDisconnectedNetworkInfo = manager.HideDisconnectedNetworkInfo;
@@ -171,7 +172,7 @@ internal static class Commands
results.Add(new ListItem(new CopyTextCommand(intInfo.GetConnectionDetails()))
{
Title = intInfo.IPv6Primary,
- Subtitle = string.Format(CultureInfo.InvariantCulture, sysIpv4DescriptionCompositeFormate, intInfo.ConnectionName),
+ Subtitle = string.Format(CultureInfo.InvariantCulture, sysIpv6DescriptionCompositeFormate, intInfo.ConnectionName),
Icon = Icons.NetworkAdapterIcon,
Details = new Details() { Title = Resources.Microsoft_plugin_ext_connection_details, Body = intInfo.GetConnectionDetails() },
});
@@ -184,7 +185,7 @@ internal static class Commands
Title = intInfo.PhysicalAddress,
Subtitle = string.Format(CultureInfo.InvariantCulture, sysMacDescriptionCompositeFormate, intInfo.Adapter, intInfo.ConnectionName),
Icon = Icons.NetworkAdapterIcon,
- Details = new Details() { Title = Resources.Microsoft_plugin_ext_connection_details, Body = intInfo.GetConnectionDetails() },
+ Details = new Details() { Title = Resources.Microsoft_plugin_ext_adapter_details, Body = intInfo.GetAdapterDetails() },
});
}
}
@@ -203,12 +204,12 @@ internal static class Commands
var isBootedInUefiMode = Win32Helpers.GetSystemFirmwareType() == FirmwareType.Uefi;
- var separateEmptyRB = manager.ShowSeparateResultForEmptyRecycleBin;
+ var hideEmptyRB = manager.HideEmptyRecycleBin;
var confirmSystemCommands = manager.ShowDialogToConfirmCommand;
var showSuccessOnEmptyRB = manager.ShowSuccessMessageAfterEmptyingRecycleBin;
// normal system commands are fast and can be returned immediately
- var systemCommands = Commands.GetSystemCommands(isBootedInUefiMode, separateEmptyRB, confirmSystemCommands, showSuccessOnEmptyRB);
+ var systemCommands = Commands.GetSystemCommands(isBootedInUefiMode, hideEmptyRB, confirmSystemCommands, showSuccessOnEmptyRB);
list.AddRange(systemCommands);
list.AddRange(networkConnectionResults);
@@ -33,11 +33,11 @@ internal static class Commands
///
/// Value indicating if the system is booted in uefi mode
- /// Value indicating if we should show two results for Recycle Bin.
+ /// Value indicating if we should hide the Empty Recycle Bin command.
/// A value indicating if the user should confirm the system commands
/// Show a success message after empty Recycle Bin.